@@ -18,10 +18,7 @@
 ##
 
 from dataclasses import dataclass
-import marshmallow_dataclass
-
 from aceql.metadata.table import Table
-from aceql.metadata.jdbc_database_meta_data import JdbcDatabaseMetaData
 
 
 @dataclass
