@@ -32,6 +32,9 @@ class TestAll(unittest.TestCase):
     def test_A(self):
 
         connection = ConnectionBuilder.get_connection()
+        headers = {'user-agent': 'aceql-client'}
+        connection.add_request_headers(headers)
+
         print()
         print("aceql version     : " + Connection.get_client_version())
         print("aceql version full: " + Connection.get_client_version_full())
